import React, { useState, useRef, useEffect, useMemo, useCallback } from "react";
import { useNavigate } from 'react-router-dom';
import {
    List,
    DatagridConfigurable,
    SearchInput,
    TopToolbar,
    SelectColumnsButton,
    EditButton,
    FilterButton,
    CreateButton,
    ExportButton,
    BulkDeleteButton,
    WrapperField,
    useRecordContext,
    useTranslate,
    useNotify,
    useListContext,
    FunctionField,
    TextField,
    NumberField,
    DateField,
    BooleanField,
    ReferenceField,
    TextInput,
    DateTimeInput,
    DateInput,
    SelectInput,
    NumberInput,
    ReferenceInput,
    ReferenceArrayInput,
    AutocompleteInput,
    DeleteButton,
    useGetRecordId,
} from 'react-admin';
import { Box, Typography, Card, Stack } from '@mui/material';
import { styled } from '@mui/material/styles';
import WaitPakinItemCreate from "./WaitPakinItemCreate";
import EmptyData from "../components/EmptyData";
import MyCreateButton from "../components/MyCreateButton";
import MyExportButton from '../components/MyExportButton';
import PageDrawer from "../components/PageDrawer";
import MyField from "../components/MyField";
import { PAGE_DRAWER_WIDTH, OPERATE_MODE, DEFAULT_PAGE_SIZE, DEFAULT_ITEM_PAGE_SIZE } from '@/config/setting';
import * as Common from '@/utils/common';

const StyledDatagrid = styled(DatagridConfigurable)(({ theme }) => ({
    '& .css-1vooibu-MuiSvgIcon-root': {
        height: '.9em'
    },
    '& .RaDatagrid-row': {
        cursor: 'auto'
    },
    '& .column-name': {
    },
    '& .opt': {
        width: 200
    },
}));

const filters = [
    <SearchInput source="condition" alwaysOn />,
    <NumberInput source="pakinId" label="table.field.waitPakinItem.pakinId" />,
    <TextInput source="maktx" label="table.field.waitPakinItem.maktx" />,
    <NumberInput source="matnrId" label="table.field.waitPakinItem.matnrId" />,
    <TextInput source="matnrCode" label="table.field.waitPakinItem.matnrCode" />,
    <NumberInput source="anfme" label="table.field.waitPakinItem.anfme" />,
    <NumberInput source="workQty" label="table.field.waitPakinItem.workQty" />,
    <TextInput source="unit" label="table.field.waitPakinItem.unit" />,
    <TextInput source="fieldsIndex" label="table.field.waitPakinItem.fieldsIndex" />,
    <NumberInput source="qty" label="table.field.waitPakinItem.qty" />,
    <TextInput source="batch" label="table.field.waitPakinItem.batch" />,
    <TextInput label="common.field.memo" source="memo" />,
    <SelectInput
        label="common.field.status"
        source="status"
        choices={[
            { id: '1', name: 'common.enums.statusTrue' },
            { id: '0', name: 'common.enums.statusFalse' },
        ]}
        resettable
    />,
]

const WaitPakinItemList = () => {
    const translate = useTranslate();
    const [createDialog, setCreateDialog] = useState(false);
    const [drawerVal, setDrawerVal] = useState(false);
    const pakinId = useGetRecordId();

    return (
        <Box display="flex">
            <List
            resource="waitPakinItem"
            filter={{pakinId: pakinId}}
                sx={{
                    flexGrow: 1,
                    transition: (theme) =>
                        theme.transitions.create(['all'], {
                            duration: theme.transitions.duration.enteringScreen,
                        }),
                    marginRight: drawerVal ? `${PAGE_DRAWER_WIDTH}px` : 0,
                }}
                title={"menu.waitPakinItem"}
                empty={<EmptyData onClick={() => { setCreateDialog(true) }} />}
                filters={filters}
                sort={{ field: "create_time", order: "desc" }}
                actions={(
                    <TopToolbar>
                        <FilterButton />
                        {/* <MyCreateButton onClick={() => { setCreateDialog(true) }} /> */}
                        <SelectColumnsButton preferenceKey='waitPakinItem' />
                        <MyExportButton />
                    </TopToolbar>
                )}
                perPage={DEFAULT_ITEM_PAGE_SIZE}
            >
                <StyledDatagrid
                    preferenceKey='waitPakinItem'
                    bulkActionButtons={() => <BulkDeleteButton mutationMode={OPERATE_MODE} />}
                    rowClick={(id, resource, record) => false}
                    omit={['id', 'createTime', 'createBy', 'memo']}
                >
                    <NumberField source="id" />
                    <NumberField source="pakinId" label="table.field.waitPakinItem.pakinId" />
                    <TextField source="maktx" label="table.field.waitPakinItem.maktx" />
                    <NumberField source="matnrId" label="table.field.waitPakinItem.matnrId" />
                    <TextField source="matnrCode" label="table.field.waitPakinItem.matnrCode" />
                    <NumberField source="anfme" label="table.field.waitPakinItem.anfme" />
                    <NumberField source="workQty" label="table.field.waitPakinItem.workQty" />
                    <TextField source="unit" label="table.field.waitPakinItem.unit" />
                    <TextField source="fieldsIndex" label="table.field.waitPakinItem.fieldsIndex" />
                    <NumberField source="qty" label="table.field.waitPakinItem.qty" />
                    <TextField source="batch" label="table.field.waitPakinItem.batch" />
                    <TextField source="updateBy$" label="common.field.updateBy" />
                    <DateField source="updateTime" label="common.field.updateTime" showTime />
                    <TextField source="createBy$" label="common.field.createBy"  />
                    <TextField source="flagDefect" label="common.field.createBy"  />
                    <DateField source="createTime" label="common.field.createTime" showTime />
                    <BooleanField source="statusBool" label="common.field.status" sortable={false} />
                    <TextField source="memo" label="common.field.memo" sortable={false} />
                </StyledDatagrid>
            </List>
            <WaitPakinItemCreate
                open={createDialog}
                setOpen={setCreateDialog}
            />
            <PageDrawer
                title='WaitPakinItem Detail'
                drawerVal={drawerVal}
                setDrawerVal={setDrawerVal}
            >
            </PageDrawer>
        </Box>
    )
}

export default WaitPakinItemList;
